@@ -45,14 +45,10 @@ import os                                        #
 
 import contextlib                                #
 import mmap                                      #
-import math                                      #
 import re                                        #
 
-import time                                      #
-import random                                    #
-
 import yaml                                      #
-import textwrap                                  #
+import site                                      #
 
 import klepto                                    #
 
@@ -484,9 +480,13 @@ def get_plugins_loader(plugin_group):
     plugins_fallback_path = str(Path.joinpath(
                               Path(__file__).parent.parent.relative_to
                               (Path(__file__).parent.parent.parent),
-                              'plugins'))
+                              'parscival_plugins'))
     plugins_paths.insert(0, plugins_fallback_path)
 
+    # add some extra paths from site-packages directories
+    for path in site.getsitepackages():
+      plugins_paths.insert(0, str(Path.joinpath(Path(path), 'parscival_plugins')))
+
     # append the plugin type to each of paths
     plugins_type_paths = [ os.path.join(p, plugin_group) for p in plugins_paths ]
     # remove non-existing paths
